# Generated by roxygen2: do not edit by hand

export(acm_article)
export(acs_article)
export(aea_article)
export(agu_article)
export(ajs_article)
export(amq_article)
export(ams_article)
export(arxiv_article)
export(asa_article)
export(bioinformatics_article)
export(biometrics_article)
export(copernicus_article)
export(copernicus_journal_abbreviations)
export(ctex)
export(ctex_article)
export(elsevier_article)
export(frontiers_article)
export(glossa_article)
export(ieee_article)
export(ims_article)
export(informs_article)
export(iop_article)
export(isba_article)
export(jasa_article)
export(jedm_article)
export(joss_article)
export(journals)
export(jss_article)
export(lipics_article)
export(lncs_article)
export(mdpi_article)
export(mnras_article)
export(oup_article)
export(peerj_article)
export(pihph_article)
export(plos_article)
export(pnas_article)
export(rjournal_article)
export(rsos_article)
export(rss_article)
export(sage_article)
export(sim_article)
export(springer_article)
export(string_to_table)
export(tf_article)
export(trb_article)
export(wellcomeor_article)
importFrom(rmarkdown,includes_to_pandoc_args)
importFrom(rmarkdown,knitr_options)
importFrom(rmarkdown,output_format)
importFrom(rmarkdown,pandoc_options)
importFrom(rmarkdown,pandoc_variable_arg)
