# pandoc-shortpaper

A template for building shortpapers in pandoc using the sensys-abstract.csl latex documentclass

## Usage

To compile all markdown files to pdf

    make

## Example

[View example PDF](http://spanners.github.io/pandoc-shortpaper/example.pdf)

## Sources

* `acm-sig-proceedings.csl`: ACM SIG Proceedings Template.
  CC-SA Naeem Esfahani and Chris Horn.
  <https://github.com/citation-style-language/styles>
* `shortpaper.latex`: ...
* `sensys-abstract.cls`: ...
* ...

