File: README_copernicus_package_7_5.txt
-------------------------------------------------------------------------
This is a README file for the Copernicus Publications LaTeX Macro Package 
copernicus_package.zip in the version 7.5, 20 October 2023
-------------------------------------------------------------------------
It consists of several files, each with its separate copyright.
This specific archive is collected for journals published by 
Copernicus Publications (Copernicus GmbH).

Copyright (C) 2023 Copernicus GmbH

E-mail: publications@copernicus.org
URL:   	https://publications.copernicus.org



Content:
- copernicus.cls: The LaTeX2e class file designed for Copernicus Publications journals. Current Version 10.1.9, 16 October 2023
- copernicus.cfg: The configuration file containing journal-specific information used by the class file. Last update 15 March 2023
- copernicus.bst: The bibliographic style file for BibTeX. Current Version 1.6, 20 October 2023 
- pdfscreencop.sty / pdfscreen.sty
- template.tex: A LaTeX template in journal style.