---
title: "Template for Preparing Your Manuscript Submission to LIPIcs Using RMarkdown"
titlerunning: "LIPIcs rticles" # optional, please use if title is longer than one line
format: "a4paper" # for A4 paper format use option "a4paper", for US-letter use option "letterpaper"
hyphenation: "UKenglish" # for british hyphenation rules use option "UKenglish", for american hyphenation rules use option "USenglish"
authorcolumns: false # activate a two columnstyle for the authors; only available in case of more than 6 authors
numberwithinsect: false # for section-numbered lemmas etc.
cleveref: true # for enabling cleveref support
autoref: true # for enabling autoref support
anonymous: false # for anonymousing the authors (e.g. for double-blind review)
thm-restate: true # for enabling thm-restate support
author:
  # mandatory, please use full name; only 1 author per \author macro; first two parameters are mandatory, other parameters can be empty. Please provide at least the name of the affiliation and the country. The full address is optional
  - name: John Q. Public
    affiliation: "Dummy University Computing Laboratory, [optional: Address], Country \\and My second affiliation, Country \\and \\url{http://www.myhomepage.edu}"
    email: johnqpublic@dummyuni.org
    orcid: "https://orcid.org/0000-0002-1825-0097"
    funding: "(Optional) author-specific funding acknowledgements"
  - name: Joan R. Public
    footnote: Optional footnote, e.g. to mark corresponding author
    affiliation: "Department of Informatics, Dummy College, [optional: Address], Country"
    email: joanrpublic@dummycollege.org
abstract: |
  Lorem ipsum dolor sit amet, consectetur adipiscing elit.
  Praesent convallis orci arcu, eu mollis dolor.
  Aliquam eleifend suscipit lacinia.
  Maecenas quam mi, porta ut lacinia sed, convallis ac dui. 
  Lorem ipsum dolor sit amet, consectetur adipiscing elit.
  Suspendisse potenti.
bibliography: bibliography
authorrunning: "J.&thinsp;Q. Public and J.&thinsp;R. Public" # mandatory. First: Use abbreviated first/middle names. Second (only in severe cases): Use first author plus 'et al.'
# A "thin space" character, ' ' or &thinsp;, is used between the two first names.
copyright: "John Q. Public and Joan R. Public" # mandatory, please use full first names. LIPIcs license is "CC-BY";  http://creativecommons.org/licenses/by/3.0/
ccdesc:
  # Please choose ACM 2012 classifications from https://dl.acm.org/ccs/ccs_flat.cfm
  concept_significance: "100"
  concept_desc: "Replace ccsdesc macro with valid one, e.g., 'Information systems $\\rightarrow$ Question answering'"
keywords: "keyword one, keyword 2, three"
# OPTIONAL:
acknowledgements: "I want to thank \\dots"
category: "Invited paper"
relatedversion: "A full version of the paper is available at https://..." # optional, e.g. full version hosted on arXiv, HAL, or other respository/website
supplement: "See code at https://github.com/.. and data at https://doi.org/..." # optional, e.g. related research data, source code, ... hosted on a repository like zenodo, figshare, GitHub, ...
funding: "(Optional) general funding statement \\dots" # optional, to capture a funding statement, which applies to all authors. Please enter author specific funding statements as fifth argument of the \author macro.
nolinenumbers: false # disable line numbering
hideLIPIcs: false # remove references to LIPIcs series (logo, DOI, ...), e.g. when preparing a pre-final version to be uploaded to arXiv or another public repository
# You will be asked to fill these in on submission with the correct information; following fields are hidded if hideLIPIcs: true:
volumemacros: |
  \EventEditors{John Q. Open and Joan R. Access}
  \EventNoEds{2}
  \EventLongTitle{42nd Conference on Very Important Topics (CVIT 2016)}
  \EventShortTitle{CVIT 2016}
  \EventAcronym{CVIT}
  \EventYear{2016}
  \EventDate{December 24--27, 2016}
  \EventLocation{Little Whinging, United Kingdom}
  \EventLogo{}
  \SeriesVolume{42}
  \ArticleNo{23}
# appendix _after_ the bibliography
appendix: |
  # Styles of lists, enumerations, and descriptions
  
  List of different predefined enumeration styles:
  
  \begin{itemize}
  \item \verb|\begin{itemize}...\end{itemize}|
  \item \dots
  \item \dots
  %\item \dots
  \end{itemize}
  
  \begin{enumerate}
  \item \verb|\begin{enumerate}...\end{enumerate}|
  \item \dots
  \item \dots
  %\item \dots
  \end{enumerate}
  
  \begin{alphaenumerate}
  \item \verb|\begin{alphaenumerate}...\end{alphaenumerate}|
  \item \dots
  \item \dots
  %\item \dots
  \end{alphaenumerate}
  
  \begin{romanenumerate}
  \item \verb|\begin{romanenumerate}...\end{romanenumerate}|
  \item \dots
  \item \dots
  %\item \dots
  \end{romanenumerate}
  
  \begin{bracketenumerate}
  \item \verb|\begin{bracketenumerate}...\end{bracketenumerate}|
  \item \dots
  \item \dots
  %\item \dots
  \end{bracketenumerate}
  
  \begin{description}
  \item[Description 1] \verb|\begin{description} \item[Description 1]  ...\end{description}|
  \item[Description 2] Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et   leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus   massa sit amet neque.
  \item[Description 3]  \dots
  %\item \dots
  \end{description}
  
  \cref{testenv-proposition} and \autoref{testenv-proposition} ...
  
  # Theorem-like environments
  
  List of different predefined enumeration styles:
  
  \begin{theorem}\label{testenv-theorem}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{theorem}
  
  \begin{lemma}\label{testenv-lemma}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{lemma}
  
  \begin{corollary}\label{testenv-corollary}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{corollary}
  
  \begin{proposition}\label{testenv-proposition}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{proposition}
  
  \begin{exercise}\label{testenv-exercise}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{exercise}
  
  \begin{definition}\label{testenv-definition}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{definition}
  
  \begin{example}\label{testenv-example}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{example}
  
  \begin{note}\label{testenv-note}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{note}
  
  \begin{note*}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{note*}
  
  \begin{remark}\label{testenv-remark}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{remark}
  
  \begin{remark*}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{remark*}
  
  \begin{claim}\label{testenv-claim}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{claim}
  
  \begin{claim*}\label{testenv-claim2}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{claim*}
  
  \begin{proof}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{proof}
  
  \begin{claimproof}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{claimproof}
  List of different predefined enumeration styles:
output:
  rticles::lipics_article: default
  # To use with bookdown feature
  bookdown::pdf_book:
    base_format: rticles::lipics_article
---

```{r setup, include = FALSE}
# deactivate addition of preamble when this format is used with bookdown
options(bookdown.theorem.preamble = FALSE)
```

# Typesetting instructions -- Summary

LIPIcs is a series of open access high-quality conference proceedings across all fields in informatics established in cooperation with Schloss Dagstuhl.
In order to do justice to the high scientific quality of the conferences that publish their proceedings in the LIPIcs series, which is ensured by the thorough review process of the respective events, we believe that LIPIcs proceedings must have an attractive and consistent layout matching the standard of the series.
Moreover, the quality of the metadata, the typesetting and the layout must also meet the requirements of other external parties such as indexing service, DOI registry, funding agencies, among others. The guidelines contained in this document serve as the baseline for the authors, editors, and the publisher to create documents that meet as many different requirements as possible.

Please comply with the following instructions when preparing your article for a LIPIcs proceedings volume.

## Minimum requirements {.unnumbered}

- Use pdflatex and an up-to-date \LaTeX{} system.
- Use further \LaTeX{} packages and custom made macros carefully and only if required.
- Use the provided sectioning macros: `\section` (`#` in Markdown), `\subsection` (`##` in Markdown), `\subsubsection` (`###` in Markdown), 
  `\paragraph` (`####` in Markdown), `\paragraph*` ((`#### header {.unnumbered}` in Markdown)), and `\subparagraph*` (`##### header {.unnumbered}` in Markdown).
-  Provide suitable graphics of at least 300dpi (preferably in PDF format).
-  Use BibTeX and keep the standard style (`plainurl`) for the bibliography.
-  Please try to keep the warnings log as small as possible. Avoid overfull `\hboxes` and any kind of warnings/errors with the referenced BibTeX entries.
-  Use a spellchecker to correct typos.

## Mandatory metadata macros {.unnumbered}

**NOTE**: _The following macros are set via the YAML header in the R Markdown template._

Please set the values of the metadata macros carefully since the information parsed from these macros will be passed to publication servers, catalogues and search engines.
Avoid placing macros inside the metadata macros. The following metadata macros/environments are mandatory:

- `\title` and, in case of long titles, `\titlerunning`.
- `\author`, one for each author, even if two or more authors have the same affiliation.
- `\authorrunning` and `\Copyright` (concatenated author names)\\
The `\author` macros and the `\Copyright` macro should contain full author names (especially with regard to the first name), while `\authorrunning` should contain abbreviated first names.
- `\ccsdesc` (ACM classification, see \url{https://www.acm.org/publications/class-2012}).
- `\keywords` (a comma-separated list of keywords).
- `\relatedversion` (if there is a related version, typically the ``full version''); please make sure to provide a persistent URL, e.\,g., at arXiv.
- `\begin{abstract}...\end{abstract}`.

#### Please do not \ldots {.unnumbered}
<!-- Do not override the \texttt{\seriesstyle}-defaults} -->
Generally speaking, please do not override the `lipics-v2019`-style defaults. To be more specific, a short checklist also used by Dagstuhl Publishing during the final typesetting is given below.
In case of `non-compliance` with these rules Dagstuhl Publishing will remove the corresponding parts of \LaTeX{} code and *replace it with the `lipics-v2019` defaults*. In serious cases, we may reject the LaTeX-source and expect the corresponding author to revise the relevant parts.

- Do not use a different main font. (For example, the `times` package is forbidden.)
- Do not alter the spacing of the `lipics-v2019.cls` style file.
- Do not use `enumitem` and `paralist`. (The `enumerate` package is preloaded, so you can use
 `\begin{enumerate}[(a)]` or the like.)
- Do not use "self-made" sectioning commands (e.\,g., `\bf My Paragraph}`).
- Do not hide large text blocks using comments or `\iffalse` $\ldots$ `\fi` constructions.
- Do not use conditional structures to include/exclude content. Instead, please provide only the content that should be published -- in one file -- and nothing else.
- Do not wrap figures and tables with text. In particular, the package `wrapfig` is not supported.
- Do not change the bibliography style. In particular, do not use author-year citations. (The
`natbib` package is not supported.)

\enlargethispage{\baselineskip}

This is only a summary containing the most relevant details. Please read the complete document "LIPIcs: Instructions for Authors and the `lipics-v2019` Class" for all details and don't hesitate to contact Dagstuhl Publishing ([mailto:publishing@dagstuhl.de](publishing@dagstuhl.de)) in case of questions or comments:
[http://drops.dagstuhl.de/styles/lipics-v2019/lipics-v2019-authors/lipics-v2019-authors-guidelines.pdf](`http://drops.dagstuhl.de/styles/lipics-v2019/lipics-v2019-authors/lipics-v2019-authors-guidelines.pdf).

# Lorem ipsum dolor sit amet

Lorem ipsum dolor sit amet, consectetur adipiscing elit \cite{DBLP:journals/cacm/Knuth74}. Praesent convallis orci arcu, eu mollis dolor. Aliquam eleifend suscipit lacinia. Maecenas quam mi, porta ut lacinia sed, convallis ac dui. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Suspendisse potenti. Donec eget odio et magna ullamcorper vehicula ut vitae libero. Maecenas lectus nulla, auctor nec varius ac, ultricies et turpis. Pellentesque id ante erat. In hac habitasse platea dictumst. Curabitur a scelerisque odio. Pellentesque elit risus, posuere quis elementum at, pellentesque ut diam. Quisque aliquam libero id mi imperdiet quis convallis turpis eleifend.

\begin{lemma}[Lorem ipsum]
\label{lemma:lorem}
Vestibulum sodales dolor et dui cursus iaculis. Nullam ullamcorper purus vel turpis lobortis eu tempus lorem semper. Proin facilisis gravida rutrum. Etiam sed sollicitudin lorem. Proin pellentesque risus at elit hendrerit pharetra. Integer at turpis varius libero rhoncus fermentum vitae vitae metus.
\end{lemma}


\begin{proof}
Cras purus lorem, pulvinar et fermentum sagittis, suscipit quis magna.

\begin{claim}
content...
\end{claim}
\begin{claimproof}
content...
\end{claimproof}

\end{proof}

\begin{corollary}[Curabitur pulvinar, \cite{DBLP:books/mk/GrayR93}]
\label{lemma:curabitur}
Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat.
\end{corollary}

\begin{proposition}\label{prop1}
This is a proposition
\end{proposition}

\autoref{prop1} and \cref{prop1} \ldots

## Curabitur dictum felis id sapien

Curabitur dictum \cref{lemma:curabitur} felis id sapien \autoref{lemma:curabitur} mollis ut venenatis tortor feugiat. Curabitur sed velit diam. Integer aliquam, nunc ac egestas lacinia, nibh est vehicula nibh, ac auctor velit tellus non arcu. Vestibulum lacinia ipsum vitae nisi ultrices eget gravida turpis laoreet. Duis rutrum dapibus ornare. Nulla vehicula vulputate iaculis. Proin a consequat neque. Donec ut rutrum urna. Morbi scelerisque turpis sed elit sagittis eu scelerisque quam condimentum. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean nec faucibus leo. Cras ut nisl odio, non tincidunt lorem. Integer purus ligula, venenatis et convallis lacinia, scelerisque at erat. Fusce risus libero, convallis at fermentum in, dignissim sed sem. Ut dapibus orci vitae nisl viverra nec adipiscing tortor condimentum \cite{DBLP:journals/cacm/Dijkstra68a}. Donec non suscipit lorem. Nam sit amet enim vitae nisl accumsan pretium.

\begin{lstlisting}[caption={Useless code},label=list:8-6,captionpos=t,float,abovecaptionskip=-\medskipamount]
for i:=maxint to 0 do
begin
    j:=square(root(i));
end;
\end{lstlisting}

## Proin ac fermentum augue

Proin ac fermentum augue. Nullam bibendum enim sollicitudin tellus egestas lacinia euismod orci mollis. Nulla facilisi. Vivamus volutpat venenatis sapien, vitae feugiat arcu fringilla ac. Mauris sapien tortor, sagittis eget auctor at, vulputate pharetra magna. Sed congue, dui nec vulputate convallis, sem nunc adipiscing dui, vel venenatis mauris sem in dui. Praesent a pretium quam. Mauris non mauris sit amet eros rutrum aliquam id ut sapien. Nulla aliquet fringilla sagittis. Pellentesque eu metus posuere nunc tincidunt dignissim in tempor dolor. Nulla cursus aliquet enim. Cras sapien risus, accumsan eu cursus ut, commodo vel velit. Praesent aliquet consectetur ligula, vitae iaculis ligula interdum vel. Integer faucibus faucibus felis.

- Ut vitae diam augue.
- Integer lacus ante, pellentesque sed sollicitudin et, pulvinar adipiscing sem.
- Maecenas facilisis, leo quis tincidunt egestas, magna ipsum condimentum orci, vitae facilisis nibh turpis et elit.

\begin{remark}
content...
\end{remark}

# Pellentesque quis tortor

Nec urna malesuada sollicitudin. Nulla facilisi. Vivamus aliquam tempus ligula eget ornare. Praesent eget magna ut turpis mattis cursus. Aliquam vel condimentum orci. Nunc congue, libero in gravida convallis \cite{DBLP:conf/focs/HopcroftPV75}, orci nibh sodales quam, id egestas felis mi nec nisi. Suspendisse tincidunt, est ac vestibulum posuere, justo odio bibendum urna, rutrum bibendum dolor sem nec tellus.

\begin{lemma} [Quisque blandit tempus nunc]
Sed interdum nisl pretium non. Mauris sodales consequat risus vel consectetur. Aliquam erat volutpat. Nunc sed sapien ligula. Proin faucibus sapien luctus nisl feugiat convallis faucibus elit cursus. Nunc vestibulum nunc ac massa pretium pharetra. Nulla facilisis turpis id augue venenatis blandit. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.
\end{lemma}

Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.

# Morbi eros magna

Morbi eros magna, vestibulum non posuere non, porta eu quam. Maecenas vitae orci risus, eget imperdiet mauris. Donec massa mauris, pellentesque vel lobortis eu, molestie ac turpis. Sed condimentum convallis dolor, a dignissim est ultrices eu. Donec consectetur volutpat eros, et ornare dui ultricies id. Vivamus eu augue eget dolor euismod ultrices et sit amet nisi. Vivamus malesuada leo ac leo ullamcorper tempor. Donec justo mi, tempor vitae aliquet non, faucibus eu lacus. Donec dictum gravida neque, non porta turpis imperdiet eget. Curabitur quis euismod ligula. 
