---
title: "Untitled"
short_title: "Untitled"
short_author: "Author 1 et. al."
authors: 
- name: "Author 1"
  affiliation: "Address"
  city: "City"
  country: "Country"
  email: "email1\\@example.com" # optional
- name: "Author 2"
  affiliation: "Address2"
  city: "City2"
  country: "Country2"
- name: "Author 3"
  affiliation: "Address2"
  city: "City2"
  country: "Country2"
  email: "email2\\@example.com"
abstract: |
  Abstract goes here
keywords: keywords
bibliography: "bibliography"
output: rticles::rss_article
---

# Introduction

This template demonstrates some of the basic latex you'll need to know to create a RSS article.

# R code

Can be inserted in regular R markdown blocks.

```{r}
x <- 1:10
x
```
