# Contributing to rticles

We welcome contributions to the **rticles** package. 

You can contribute in many ways: 

* By opening issues to give feedback and share ideas.
* By fixing typos in documentations
* By submitting Pull Request (PR) to fix some opened issues
* By submitting Pull Request (PR) to suggest some new features. (It is considered good practice to open issues before to discuss ideas)

## To submit a contribution using a Pull Request:

1.  [Fork](https://github.com/rstudio/rticles/fork) the repository and make your changes in a new branch specific to the PR. It is ok to edit a file in this repository using the `Edit` button on Github if the change is simple enough.

2. For significant changes (e.g not required for fixing typos), ensure that you have signed the [individual](https://www.rstudio.com/wp-content/uploads/2014/06/rstudioindividualcontributoragreement.pdf) or [corporate](https://www.rstudio.com/wp-content/uploads/2014/06/rstudiocorporatecontributoragreement.pdf) contributor agreement as appropriate. You can send the signed copy to <jj@posit.co>.

3.  Submit the [pull request](https://help.github.com/articles/using-pull-requests). It is ok to submit as draft if you are still working on it but would like some feedback from us. It always good to share in the open that you are working on it.

4. You will be asked to check that you're PR meets some requirements. See the [PR template](https://pkgs.rstudio.com/rticles/PULL_REQUEST_TEMPLATE.html).

We'll try to be as responsive as possible in reviewing and accepting pull requests. Appreciate your contributions very much!
