---
title: Template for preparing your research report submission to PeerJ using RMarkdown
preprint: false
author: 
  - name: Barbara McClintock
    affiliation: 1
    corresponding: true
    email: mcclintockb@cshl.edu
  - name: Charles E. Darwin
    affiliation: 2
affiliation:
  - code: 1
    address: Cold Spring Harbor Laboratory, One Bungtown Road Cold Spring Harbor, NY 11724
  - code: 2
    address: Down House, Luxted Rd, Downe, Orpington BR6 7JT, UK
abstract: >
  The abstract of the article.
  It can also be on *multiple* lines.
bibliography: sample.bib
output:
  rticles::peerj_article: default
  bookdown::pdf_book:
    base_format: rticles::peerj_article # for using bookdown features like \@ref()
---


# Introduction {-}

Your introduction goes here! Some examples of commonly used commands and features are listed below, to help you get started.

If you have a question, please use the help menu in the top right of the screen to get in touch. When your article or pre-print is complete, use the "Submit to PeerJ" button in the topbar to send your files to PeerJ.

## About PeerJ {-}

PeerJ is an award-winning open access publisher covering the biological and medical sciences.  PeerJ provides authors with three publication venues: *PeerJ* and *PeerJ Computer Science* (peer-reviewed academic journals) and *PeerJ PrePrints* (a 'pre-print server'). See https://peerj.com/about/publications/ for more information.

The PeerJ model allows an author to publish articles in their peer-reviewed journal via the purchase of a lifetime Publication Plan. Prices start from just \$99 (a one-off payment) which entitles an author to the lifetime ability to publish 1 article per year for free. Publication in PeerJ PrePrints is entirely free.

# Some \LaTeX{} Examples {-}

Use section and subsection commands to organize your document. \LaTeX{} handles all the formatting and numbering automatically. Use ref and label commands for cross-references.

## Figures and Tables {-}

Use the table and tabular commands for basic tables --- see Table \@ref(tab:widgets), for example. You can upload a figure (JPEG, PNG or PDF) using the project menu. To include it in your document, use the includegraphics command as in the code for Figure \@ref(fig:view) below.

Standard \LaTeX references will work as well (e.g. Fig. \ref{fig:view}).

<!-- There are three ways to include figures: -->
<!-- 1. The LaTeX way -->
<!-- 

\begin{figure}[ht]
\centering
\includegraphics[width=\linewidth]{view}
\caption{An example image.}
\label{fig:view}
\end{figure} 

 -->

<!-- 2. The RMarkdown way -->

```{r view, out.width = "100%", fig.cap = "An example image.", echo = FALSE}
knitr::include_graphics("view.jpg")
```


<!-- 3. The pandoc way -->
<!-- 

![An example image. Text *can* be processed with markdown.](view.jpg){#view width = 100%}

 -->

<!-- 
\begin{table}[ht]
\centering
\begin{tabular}{l|r}
Item & Quantity \\\hline
Widgets & 42 \\
Gadgets & 13
\end{tabular}
\caption{\label{tab:widgets}An example table.}
\end{table}
-->

Item     Quantity
------- ---------
Widgets        42
Gadgets        13

Table: (\#tab:widgets) An Example Table.

## Citations {-}

LaTeX formats citations and references automatically using the bibliography records in your .bib file, which you can edit via the project menu. Use the cite command for an inline citation, like @Figueredo:2009dg, and the citep command for a citation in parentheses [@Figueredo:2009dg].

## Mathematics {-}

\LaTeX{} is great at typesetting mathematics. Let $X_1, X_2, \ldots, X_n$ be a sequence of independent and identically distributed random variables with $\text{E}[X_i] = \mu$ and $\text{Var}[X_i] = \sigma^2 < \infty$, and let
$$S_n = \frac{X_1 + X_2 + \cdots + X_n}{n}
      = \frac{1}{n}\sum_{i}^{n} X_i$$
denote their mean. Then as $n$ approaches infinity, the random variables $\sqrt{n}(S_n - \mu)$ converge in distribution to a normal $\mathcal{N}(0, \sigma^2)$.

## Lists {-}

You can make lists with automatic numbering \dots


1. Like this,
1. and like this.

or bullet points...

- Like this,
- and like this.

or with descriptions...

- **Word** Definition
- **Concept** Explanation
- **Idea** Text


We hope you find write\LaTeX\ useful for your PeerJ submission, and please let us know if you have any feedback. Further examples with dummy text are included in the following pages.

# Methods {-}

This is an equation inserted using LaTeX syntax directly.

\begin{equation}
\cos^3 \theta =\frac{1}{4}\cos\theta+\frac{3}{4}\cos 3\theta
\label{eq:refname2}
\end{equation}

You can also use `$$..$$` to achieve the same

$$
\cos^3 \theta =\frac{1}{4}\cos\theta+\frac{3}{4}\cos 3\theta
$$

## Subsection {-}

Use `{-}` after a header section so that it is unnumbered.

#### Paragraph  

Header level 4 are equivalent to `\paragraph{}`

## Subsection {-}


You can insert figure using R code chunk with different options

```{r results, fig.width = 5, fig.height = 4, out.width = "100%", fig.cap = "In-text Picture", echo = FALSE}
time = seq(1.5, 8, 0.1)
plot(time, sin(time), type = "l", xlab = "time [s]", ylab = "amplitude [m]", 
     cex.main = 2, col = "blue", lwd = 3, font = 2, font.main = 2)
```


You can reference figure if you use **bookdown** format extensions as shown in YAML header

# Results and Discussion {-}

This is another section

## Subsection {-}

Which shows level 2

### Subsubsection {-}

And level 3 headers

### Subsubsection {-}

with multiple subsubsections

## Subsection {-}

and subsections

# Acknowledgments {-}

So long and thanks for all the fish.

# References
