---
title: Wellcome Open Research Article Template
titlenote: The title should be detailed enough for someone to know whether the article would be of interest to them, but also concise. Please ensure the broadness and claims within the title are appropriate to the content of the article itself.
author:
  - name: Author Name1
    affil: 
    - 1
    - 2
    email: author1@email.com
  - name: Author Name2
    affil: 2
    email: author2@email.com
    corresponding: TRUE
address:
  - code: 1
    address: Address1
  - code: 2
    address: Address2
include-before: |
  Please list all authors that played a significant role in the research involved in the article. Please provide full affiliation information (including full institutional address, ZIP code and e-mail address) for all authors, and identify who is/are the corresponding author(s).
abstract: |
  Abstracts should be up to 300 words and provide a succinct summary of the article. Although the abstract should explain why the article might be interesting, care should be taken not to inappropriately over-emphasise the importance of the work described in the article. Citations should not be used in the abstract, and the use of abbreviations should be minimized. If you are writing a Research or Systematic Review article, please structure your abstract into Background, Methods, Results, and Conclusions.
keywords: |
  Please list up to eight keywords to help readers interested in your article find it more easily.

date: "`r Sys.Date()`"
bibliography: sample.bib
link-citations: TRUE
# Setting CSL will be necessary if you use `citation_packahe = "default"`
# You can download the csl file if preferred and use it locally with `csl: elsevier-vancouver.csl`
# csl: https://www.zotero.org/styles/elsevier-vancouver
output: 
  rticles::wellcomeor_article:
    citation_package: natbib
  bookdown::pdf_book:
    base_format: rticles::wellcomeor_article
    citation_package: natbib
---

*Text based on Wellcome Open Research [Overleaf Latex
template](https://www.overleaf.com/project/6131911644b635ad3aaa4cb2)*

\bigskip 

Please list all authors that played a significant role in the research involved
in the article. Please provide full affiliation information (including full
institutional address, ZIP code and e-mail address) for all authors, and
identify who is/are the corresponding author(s).

# Introduction

The format of the main body of the article is flexible: it should be concise and
in the format most appropriate to displaying the content of the article.

Some examples of commonly used \LaTeX{} commands and features are listed below,
to help you get started.

## Sections

Use section and subsection commands to organize your document. \LaTeX{} handles
all the formatting and numbering automatically. Use ref and label commands for
cross-references.

## Tables

Use the table and tabledata commands for basic tables --- see
Table \@ref(tab:widgets), for example.

```{=tex}
\begin{table}[h!]
  \hrule \vspace{0.1cm}
  \caption{\label{tab:widgets}An example of a simple table with caption.}
  \centering
  \begin{tabledata}{llr}
    \header First name & Last Name & Grade \\
    \row John & Doe & $7.5$ \\
    \row Richard & Miles & $2$ \\
  \end{tabledata}
\end{table}
```

Similarly, you can insert an R chunk and reference with 
[Bookdown referencing](https://bookdown.org/yihui/bookdown/tables.html), i.e.,
`\@ref(tab:label)`.

## Figures

You can upload a figure (JPEG, PNG or PDF) using the files menu. To include it
in your document, use the includegraphics \LaTeX{} command (see the example
below in the source code), or insert using an R chunk and reference with
[Bookdown referencing](https://bookdown.org/yihui/bookdown/figures.html), i.e.,
`\@ref(fig:label)`.

Please give figures appropriate filenames eg: figure1.pdf, figure2.png.

Figure legends should briefly describe the key messages of the figure such that
the figure can stand alone from the main text. However, all figures should also
be discussed in the article text. Each legend should have a concise title of no
more than 15 words. The legend itself should be succinct, while still explaining
all symbols and abbreviations. Avoid lengthy descriptions of methods.

For any figures reproduced from another publication (as long as appropriate
permission has been obtained from the copyright holder ---see under the heading
'Submission'), please include a line in the legend to state that: 'This figure
has been reproduced with kind permission from [include original publication
citation]'.

```{=tex}
\begin{figure} 
  \centering 
  \includegraphics[width=0.4\textwidth]{frog.jpg}
  \caption{\label{fig:your-figure}Your figure legend goes here; it should be
  succinct, while still explaining all symbols and abbreviations. } 
\end{figure}
```

## Mathematics

\LaTeX{} is great at typesetting mathematics. Let $X_1, X_2, \ldots, X_n$ be a
sequence of independent and identically distributed random variables with
$\text{E}[X_i] = \mu$ and $\text{Var}[X_i] = \sigma^2 < \infty$, and let $$S_n =
\frac{X_1 + X_2 + \cdots + X_n}{n} = \frac{1}{n}\sum_{i}^{n} X_i$$ denote their
mean. Then as $n$ approaches infinity, the random variables
$\sqrt{n}(S_n - \mu)$ converge in distribution to a normal
$\mathcal{N}(0, \sigma^2)$.

## Lists

You can make lists with automatic numbering \dots

1.  Like this,
2.  and like this.

\dots or bullet points \dots

-   Like this,
-   and like this.

# Methods

Methods should include a brief discussion of allowances made (if any) for
controlling bias or unwanted sources of variability, and the limitations of the
datasets.

# Results

This section is not essential for Web Tool papers.

# Discussion

The discussion should include the implications of the article results in view of
prior work in this field.

# Conclusions

Please state what you think are the main conclusions that can be realistically
drawn from the findings in the paper, taking care not to make claims that cannot
be supported.

## Author contributions

In order to give appropriate credit to each author of an article, the individual
contributions of each author to the manuscript should be detailed in this
section. We recommend using author initials and then stating briefly how they
contributed.

## Competing interests

All financial, personal, or professional competing interests for any of the
authors that could be construed to unduly influence the content of the article
must be disclosed and will be displayed alongside the article.

## Grant information

Please state who funded the work discussed in this article, whether it is your
employer, a grant funder etc. Please do not list funding that you have that is
not relevant to this specific piece of research. For each funder, please state
the funder's name, the grant number where applicable, and the individual to whom
the grant was assigned.

## Acknowledgements

This section should acknowledge anyone who contributed to the research or the
article but who does not qualify as an author based on the criteria provided
earlier (e.g. someone or an organisation that provided writing assistance).
Please state how they contributed; authors should obtain permission to
acknowledge from all those mentioned in the Acknowledgements section.

Please do not list grant funding in this section.

# Handling References

References can be listed in any standard referencing style that uses a numbering
system(i.e. not Harvard referencing style), and should be consistent between
references within a given article.

Reference management systems such as Zotero provide options for exporting
bibliographies as Bib\TeX{} files. Bib\TeX{} is a bibliographic tool that is
used with \LaTeX{} to help organize the user's references and create a
bibliography. This template contains an example of such a file,
\texttt{sample.bib}, which can be replaced with your own. You can \LaTeX{}
command  \verb|\cite| to create in-text citationsor by using
RMarkdown/Bookdown's citations [@Smith:2012qr], and [@Smith:2013jd]
