# rjournal_article() is deprecated

    Code
      x <- rjournal_article()
    Condition
      Warning:
      `rjournal_article()` was deprecated in rticles 0.25.
      i Please use `rjtools::rjournal_pdf_article()` instead.
      i See official recommandation at https://rjournal.github.io/submissions.html

